/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.reporters.pdd;

// REMPL API classes
import com.rempl.api.Element;

// collection management
import java.util.ArrayList;
import java.util.Collection;

/**
 * One ticket.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: Ticket.java 706 2011-03-16 20:51:06Z yegor256@yahoo.com $
 */
final class Ticket {

    /**
     * Name of the ticket.
     * @see #Ticket(String)
     */
    private String name;

    /**
     * List of puzzles attached.
     * @see #append(Element)
     */
    private Collection<Element> puzzles = new ArrayList<Element>();

    /**
     * Public ctor.
     * @param pname The name of the ticket
     */
    public Ticket(final String pname) {
        this.name = pname;
    }

    /**
     * Get name of the ticket.
     * @return Name of the ticket
     */
    public String getName() {
        return this.name;
    }

    /**
     * Get list of attached puzzles.
     * @return List of puzzles
     */
    public Collection<Element> getPuzzles() {
        return this.puzzles;
    }

    /**
     * Add new puzzle here.
     * @param puzzle New puzzle
     */
    public void append(final Element puzzle) {
        this.puzzles.add(puzzle);
    }

}
